summaryrefslogtreecommitdiffstats
path: root/examples/dbus/remotecontrolledcar/controller
diff options
context:
space:
mode:
authorOswald Buddenhagen <oswald.buddenhagen@nokia.com>2012-08-02 20:49:12 +0200
committerQt by Nokia <qt-info@nokia.com>2012-08-07 18:55:43 +0200
commit5bea177ab11f057849d2b072c4ed088ef4e052f0 (patch)
treed6f7a0e5809033d59e9437cf336004b7de50727e /examples/dbus/remotecontrolledcar/controller
parent0ef4bf1c1e77d4b11f5f17babdd0065723901a7d (diff)
fix class and file names in the d-bus examples
some omissions from the com.trolltech => org.example replacement. Change-Id: I078c272fc3729fc7b9e9cd3e6ede7c21f0386b62 Reviewed-by: Thiago Macieira <thiago.macieira@intel.com>
Diffstat (limited to 'examples/dbus/remotecontrolledcar/controller')
-rw-r--r--examples/dbus/remotecontrolledcar/controller/car_interface.cpp6
-rw-r--r--examples/dbus/remotecontrolledcar/controller/car_interface.h12
-rw-r--r--examples/dbus/remotecontrolledcar/controller/controller.cpp2
-rw-r--r--examples/dbus/remotecontrolledcar/controller/controller.h2
4 files changed, 11 insertions, 11 deletions
diff --git a/examples/dbus/remotecontrolledcar/controller/car_interface.h b/examples/dbus/remotecontrolledcar/controller/car_interface.h
index 8d624b3746..1696b2fe83 100644
--- a/examples/dbus/remotecontrolledcar/controller/car_interface.h
+++ b/examples/dbus/remotecontrolledcar/controller/car_interface.h
@@ -62,7 +62,7 @@
/*
* Proxy class for interface org.example.Examples.CarInterface
*/
-class ComTrolltechExamplesCarInterfaceInterface: public QDBusAbstractInterface
+class OrgExampleExamplesCarInterfaceInterface: public QDBusAbstractInterface
{
Q_OBJECT
public:
@@ -70,9 +70,9 @@ public:
{ return "org.example.Examples.CarInterface"; }
public:
- ComTrolltechExamplesCarInterfaceInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = 0);
+ OrgExampleExamplesCarInterfaceInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = 0);
- ~ComTrolltechExamplesCarInterfaceInterface();
+ ~OrgExampleExamplesCarInterfaceInterface();
public Q_SLOTS: // METHODS
inline QDBusPendingReply<> accelerate()
@@ -103,10 +103,10 @@ Q_SIGNALS: // SIGNALS
void crashed();
};
-namespace com {
- namespace trolltech {
+namespace org {
+ namespace example {
namespace Examples {
- typedef ::ComTrolltechExamplesCarInterfaceInterface CarInterface;
+ typedef ::OrgExampleExamplesCarInterfaceInterface CarInterface;
}
}
}
diff --git a/examples/dbus/remotecontrolledcar/controller/controller.cpp b/examples/dbus/remotecontrolledcar/controller/controller.cpp
index fb829da17c..9c4950acdc 100644
--- a/examples/dbus/remotecontrolledcar/controller/controller.cpp
+++ b/examples/dbus/remotecontrolledcar/controller/controller.cpp
@@ -47,7 +47,7 @@ Controller::Controller(QWidget *parent)
: QWidget(parent)
{
ui.setupUi(this);
- car = new com::trolltech::Examples::CarInterface("org.example.CarExample", "/Car",
+ car = new org::example::Examples::CarInterface("org.example.CarExample", "/Car",
QDBusConnection::sessionBus(), this);
startTimer(1000);
}
diff --git a/examples/dbus/remotecontrolledcar/controller/controller.h b/examples/dbus/remotecontrolledcar/controller/controller.h
index 2d8c9031ad..0ce8a8ead3 100644
--- a/examples/dbus/remotecontrolledcar/controller/controller.h
+++ b/examples/dbus/remotecontrolledcar/controller/controller.h
@@ -62,7 +62,7 @@ private slots:
private:
Ui::Controller ui;
- com::trolltech::Examples::CarInterface *car;
+ org::example::Examples::CarInterface *car;
};
#endif
diff --git a/examples/dbus/remotecontrolledcar/controller/car_interface.cpp b/examples/dbus/remotecontrolledcar/controller/car_interface.cpp
index 8f495ea62c..3a7020eac7 100644
--- a/examples/dbus/remotecontrolledcar/controller/car_interface.cpp
+++ b/examples/dbus/remotecontrolledcar/controller/car_interface.cpp
@@ -50,15 +50,15 @@
#include "car_interface.h"
/*
* Implementation of interface class ComTrolltechExamplesCarInterfaceInterface
*/
-ComTrolltechExamplesCarInterfaceInterface::ComTrolltechExamplesCarInterfaceInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
+OrgExampleExamplesCarInterfaceInterface::OrgExampleExamplesCarInterfaceInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
: QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}
-ComTrolltechExamplesCarInterfaceInterface::~ComTrolltechExamplesCarInterfaceInterface()
+OrgExampleExamplesCarInterfaceInterface::~OrgExampleExamplesCarInterfaceInterface()
{
}
@@ -50,15 +50,15 @@
#include "car_interface.h"
/*
- * Implementation of interface class ComTrolltechExamplesCarInterfaceInterface
+ * Implementation of interface class OrgExampleExamplesCarInterfaceInterface
*/